searchData={"items":[{"type":"module","title":"Garnish","doc":"Implements the `:ssh_server_channel` behaviour on behalf of the app.","ref":"Garnish.html"},{"type":"opaque","title":"Garnish.t/0","doc":"","ref":"Garnish.html#t:t/0"},{"type":"behaviour","title":"Garnish.App","doc":"Defines the `Garnish.App` behaviour. It provides the structure for\narchitecting both large and small terminal applications, over SSH.\n\nThe entrypoint to the application is defined by parameters to the\n[ssh_cli](https://www.erlang.org/doc/apps/ssh/ssh.html#t:ssh_cli_daemon_option/0)\ndaemon option.","ref":"Garnish.App.html"},{"type":"behaviour","title":"A Simple Example - Garnish.App","doc":"# Assumes that `:ssh_cli` daemon option was set to:\n    # ssh_cli: {Garnish, {Counter.App, []}}\n\n    defmodule Counter.App do\n      @behaviour Garnish.App\n\n      # Initialize our model state\n      def init(_context), do: {:ok, 0}\n\n      # Respond to key presses\n      def handle_key(%{key: key}, model) do\n        case key do\n          ?+ -> {:ok, model + 1}\n          ?- -> {:ok, model - 1}\n          _ -> {:ok, model, render: false}\n      end\n\n      # Turn the model into view\n      def render(model) do\n        view do\n          label(content: \"Counter is #{model} (+/-)\")\n        end\n      end\n    end","ref":"Garnish.App.html#module-a-simple-example"},{"type":"behaviour","title":"Callbacks - Garnish.App","doc":"The behaviour describes 3 mandatory and 3 optional callbacks. The mandatory\ncallbacks are:\n\n* `c:init/1` for setting the initial model state\n* `c:handle_key/2` for handling keys from the client\n* `c:render/1` for rendering the model to a view\n\nThe three optional callbacks are:\n\n* `c:handle_resize/2` for handling resize events\n* `c:handle_info/2` for handling all other messages\n* `c:terminate/2` for handling process termination\n\nFor all the `handle_/2` callbacks, it is possible to disable re-rendering,\neven after a model update, by returning `[render: false]` from the callback.\nThis is useful if the model has 'private' data that does not itself affect\nthe view.","ref":"Garnish.App.html#module-callbacks"},{"type":"callback","title":"Garnish.App.handle_info/2","doc":"Handle an event.\n\nUsed to handle any non-key/non-resize message. This callback is optional. If\nnot specified, the message is ignored.","ref":"Garnish.App.html#c:handle_info/2"},{"type":"callback","title":"Garnish.App.handle_key/2","doc":"Handle a key-press from the client.\n\nThe key event is a map containing the following entries:\n\n- `key` an integer or mnenomic representing the key pressed. Most literal\n  keys are expressed as an integer. Other keys are expressed as an atom\n  based on their terminal settings such as `:kcud1` for left-arrow. The mnemomics\n  are derived from their terminfo specifications (see [the terminfo manual page](https://man7.org/linux/man-pages/man5/terminfo.5.html))\n  for more details.\n- `alt` a boolean indicating whether the alt-key was pressed\n- `data` the raw data from the connection","ref":"Garnish.App.html#c:handle_key/2"},{"type":"callback","title":"Garnish.App.handle_resize/2","doc":"Handle a resize event from the client.\n\nThis callback is optional. If not specified, the default behaviour is render the\nexisting model again (for the new size).","ref":"Garnish.App.html#c:handle_resize/2"},{"type":"callback","title":"Garnish.App.init/1","doc":"The `init/1` callback defines the initial model. The context is a map with the\nfollowing keys:\n\n- `args` the args passed as passed to `ssh_cli`, defaults to `[]`\n- `size` the size of the initial window passed as `{rows, cols}`\n- `environment` the environment passed from the client\n- `connection` the ssh connection reference. This may be used to query information\n  via `:ssh.connection_info/1`\n\nThe callback should return the initial state on success or an error otherwise.\nAdditionally, on success, the client may return some options that adjust the behaviour\nof the app. The currently supported values are:\n\n- `quit_keys` a list of integers that determine which keys will automatically close\n  the app. If not specified, defaults to ctrl-c (`[3]`).","ref":"Garnish.App.html#c:init/1"},{"type":"callback","title":"Garnish.App.render/1","doc":"The `render/1` callback defines how to render the model as a view.\n\nIt should return a `Garnish.Renderer.Element` with the `:view` tag. For example:\n\n    @impl true\n    def render(model) do\n      view do\n        label(content: \"Hello, #{model.name}!\")\n      end\n    end","ref":"Garnish.App.html#c:render/1"},{"type":"callback","title":"Garnish.App.terminate/2","doc":"Handle termination of the application.\n\nThis callback is optional and can be used for arbitrary clean-up. Note that the\nclient's session has already been closed by the time this callback in invoked.","ref":"Garnish.App.html#c:terminate/2"},{"type":"type","title":"Garnish.App.col_count/0","doc":"","ref":"Garnish.App.html#t:col_count/0"},{"type":"type","title":"Garnish.App.context/0","doc":"","ref":"Garnish.App.html#t:context/0"},{"type":"type","title":"Garnish.App.dimension/0","doc":"","ref":"Garnish.App.html#t:dimension/0"},{"type":"type","title":"Garnish.App.handle_opt/0","doc":"","ref":"Garnish.App.html#t:handle_opt/0"},{"type":"type","title":"Garnish.App.handle_opts/0","doc":"","ref":"Garnish.App.html#t:handle_opts/0"},{"type":"type","title":"Garnish.App.init_opt/0","doc":"","ref":"Garnish.App.html#t:init_opt/0"},{"type":"type","title":"Garnish.App.init_opts/0","doc":"","ref":"Garnish.App.html#t:init_opts/0"},{"type":"type","title":"Garnish.App.key_event/0","doc":"","ref":"Garnish.App.html#t:key_event/0"},{"type":"type","title":"Garnish.App.model/0","doc":"","ref":"Garnish.App.html#t:model/0"},{"type":"type","title":"Garnish.App.msg/0","doc":"","ref":"Garnish.App.html#t:msg/0"},{"type":"type","title":"Garnish.App.reason/0","doc":"","ref":"Garnish.App.html#t:reason/0"},{"type":"type","title":"Garnish.App.row_count/0","doc":"","ref":"Garnish.App.html#t:row_count/0"},{"type":"module","title":"Garnish.Cell","doc":"Represents a cell, a character at a position, along with the cell's\nbackground and foreground colors.","ref":"Garnish.Cell.html"},{"type":"function","title":"Garnish.Cell.empty/0","doc":"","ref":"Garnish.Cell.html#empty/0"},{"type":"type","title":"Garnish.Cell.t/0","doc":"","ref":"Garnish.Cell.html#t:t/0"},{"type":"module","title":"Garnish.Constants","doc":"Defines constants from the termbox library. These can be used e.g. to set a\nformatting attributes or to identify keys passed in an event.","ref":"Garnish.Constants.html"},{"type":"function","title":"Garnish.Constants.attribute/1","doc":"Retrieves an attribute constant by name","ref":"Garnish.Constants.html#attribute/1"},{"type":"function","title":"Examples - Garnish.Constants.attribute/1","doc":"iex> attribute(:bold)\n    0x0100\n    iex> attribute(:underline)\n    0x0200","ref":"Garnish.Constants.html#attribute/1-examples"},{"type":"function","title":"Garnish.Constants.attributes/0","doc":"Retrieves the mapping of attribute constants.","ref":"Garnish.Constants.html#attributes/0"},{"type":"function","title":"Garnish.Constants.color/1","doc":"Retrieves a color constant by name","ref":"Garnish.Constants.html#color/1"},{"type":"function","title":"Examples - Garnish.Constants.color/1","doc":"iex> color(:red)\n    0x02\n    iex> color(:blue)\n    0x05","ref":"Garnish.Constants.html#color/1-examples"},{"type":"function","title":"Garnish.Constants.colors/0","doc":"Retrieves the mapping of color constants.","ref":"Garnish.Constants.html#colors/0"},{"type":"function","title":"Garnish.Constants.error_code/1","doc":"Retrieves an error code constant by name","ref":"Garnish.Constants.html#error_code/1"},{"type":"function","title":"Examples - Garnish.Constants.error_code/1","doc":"iex> error_code(:unsupported_terminal)\n    -1","ref":"Garnish.Constants.html#error_code/1-examples"},{"type":"function","title":"Garnish.Constants.error_codes/0","doc":"Retrieves the mapping of error code constants.","ref":"Garnish.Constants.html#error_codes/0"},{"type":"function","title":"Garnish.Constants.event_type/1","doc":"Retrieves an event type constant by name","ref":"Garnish.Constants.html#event_type/1"},{"type":"function","title":"Examples - Garnish.Constants.event_type/1","doc":"iex> event_type(:key)\n    0x01\n    iex> event_type(:resize)\n    0x02\n    iex> event_type(:mouse)\n    0x03","ref":"Garnish.Constants.html#event_type/1-examples"},{"type":"function","title":"Garnish.Constants.event_types/0","doc":"Retrieves the mapping of event type constants.","ref":"Garnish.Constants.html#event_types/0"},{"type":"function","title":"Garnish.Constants.hide_cursor/0","doc":"Retrieves the hide cursor constant.","ref":"Garnish.Constants.html#hide_cursor/0"},{"type":"function","title":"Examples - Garnish.Constants.hide_cursor/0","doc":"iex> hide_cursor()\n    -1","ref":"Garnish.Constants.html#hide_cursor/0-examples"},{"type":"function","title":"Garnish.Constants.input_mode/1","doc":"Retrieves an input mode constant by name","ref":"Garnish.Constants.html#input_mode/1"},{"type":"function","title":"Examples - Garnish.Constants.input_mode/1","doc":"iex> input_mode(:esc)\n    1\n    iex> input_mode(:esc_with_mouse)\n    5","ref":"Garnish.Constants.html#input_mode/1-examples"},{"type":"function","title":"Garnish.Constants.input_modes/0","doc":"Retrieves the mapping of input mode constants.","ref":"Garnish.Constants.html#input_modes/0"},{"type":"function","title":"Garnish.Constants.key/1","doc":"Retrieves a key constant by name","ref":"Garnish.Constants.html#key/1"},{"type":"function","title":"Examples - Garnish.Constants.key/1","doc":"iex> key(:esc)\n    0x1B\n    iex> key(:space)\n    0x20","ref":"Garnish.Constants.html#key/1-examples"},{"type":"function","title":"Garnish.Constants.keys/0","doc":"Retrieves the mapping of key constants for use with termbox.\n\nThese are based on terminfo constants. Note that there's some overlap\nof terminfo values. For example, it's not possible to distinguish between\n` ` and `ctrl-h`.","ref":"Garnish.Constants.html#keys/0"},{"type":"function","title":"Garnish.Constants.output_mode/1","doc":"Retrieves an output mode constant by name","ref":"Garnish.Constants.html#output_mode/1"},{"type":"function","title":"Examples - Garnish.Constants.output_mode/1","doc":"iex> output_mode(:term_256)\n    2","ref":"Garnish.Constants.html#output_mode/1-examples"},{"type":"function","title":"Garnish.Constants.output_modes/0","doc":"Retrieves the mapping of output mode constants.","ref":"Garnish.Constants.html#output_modes/0"},{"type":"type","title":"Garnish.Constants.attribute/0","doc":"","ref":"Garnish.Constants.html#t:attribute/0"},{"type":"type","title":"Garnish.Constants.color/0","doc":"","ref":"Garnish.Constants.html#t:color/0"},{"type":"type","title":"Garnish.Constants.constant/0","doc":"","ref":"Garnish.Constants.html#t:constant/0"},{"type":"type","title":"Garnish.Constants.error_code/0","doc":"","ref":"Garnish.Constants.html#t:error_code/0"},{"type":"type","title":"Garnish.Constants.event_type/0","doc":"","ref":"Garnish.Constants.html#t:event_type/0"},{"type":"type","title":"Garnish.Constants.hide_cursor/0","doc":"","ref":"Garnish.Constants.html#t:hide_cursor/0"},{"type":"type","title":"Garnish.Constants.input_mode/0","doc":"","ref":"Garnish.Constants.html#t:input_mode/0"},{"type":"type","title":"Garnish.Constants.key/0","doc":"","ref":"Garnish.Constants.html#t:key/0"},{"type":"type","title":"Garnish.Constants.output_mode/0","doc":"","ref":"Garnish.Constants.html#t:output_mode/0"},{"type":"module","title":"Garnish.Position","doc":"Represents a position on the screen by encoding a pair of cartesian\ncoordinates. The origin is the top-left-most character on the screen\n`(0, 0)`, while x and y increase from left to right and top to bottom,\nrespectively.","ref":"Garnish.Position.html"},{"type":"function","title":"Garnish.Position.translate/3","doc":"Translates (shifts) a position by some delta x and y.\n\nReturns a new `%Position{}`.","ref":"Garnish.Position.html#translate/3"},{"type":"function","title":"Examples - Garnish.Position.translate/3","doc":"iex> translate(%Position{x: 0, y: 0}, 1, 2)\n    %Position{x: 1, y: 2}\n    iex> translate(%Position{x: 10, y: 0}, -1, 0)\n    %Position{x: 9, y: 0}","ref":"Garnish.Position.html#translate/3-examples"},{"type":"function","title":"Garnish.Position.translate_x/2","doc":"Translates a position by a delta x.\n\nReturns a new `%Position{}`.","ref":"Garnish.Position.html#translate_x/2"},{"type":"function","title":"Examples - Garnish.Position.translate_x/2","doc":"iex> translate_x(%Position{x: 0, y: 0}, 2)\n    %Position{x: 2, y: 0}\n    iex> translate_x(%Position{x: 2, y: 0}, -1)\n    %Position{x: 1, y: 0}","ref":"Garnish.Position.html#translate_x/2-examples"},{"type":"function","title":"Garnish.Position.translate_y/2","doc":"Translates a position by a delta y.\n\nReturns a new `%Position{}`.","ref":"Garnish.Position.html#translate_y/2"},{"type":"function","title":"Examples - Garnish.Position.translate_y/2","doc":"iex> translate_y(%Position{x: 0, y: 0}, 2)\n    %Position{x: 0, y: 2}\n    iex> translate_y(%Position{x: 0, y: 2}, -1)\n    %Position{x: 0, y: 1}","ref":"Garnish.Position.html#translate_y/2-examples"},{"type":"type","title":"Garnish.Position.t/0","doc":"","ref":"Garnish.Position.html#t:t/0"},{"type":"behaviour","title":"Garnish.Renderer","doc":"Logic to render a view tree.\n\nThis API is still under development.","ref":"Garnish.Renderer.html"},{"type":"function","title":"Garnish.Renderer.render/2","doc":"Renders a view tree to canvas, given a canvas and a root element (an element\nwith the `:view` tag).\n\nThe tree is rendered by recursively rendering each element in the hierarchy.\nThe canvas serves as both the accumulator for rendered cells at each stage and\nas the box representing available space for rendering, which shrinks as this\nspace is consumed.","ref":"Garnish.Renderer.html#render/2"},{"type":"callback","title":"Garnish.Renderer.render/3","doc":"","ref":"Garnish.Renderer.html#c:render/3"},{"type":"function","title":"Garnish.Renderer.render_tree/2","doc":"","ref":"Garnish.Renderer.html#render_tree/2"},{"type":"function","title":"Garnish.Renderer.validate_tree/1","doc":"Validates the hierarchy of a view tree given the root element.\n\nUsed by the render/2 function to prevent strange errors that may otherwise\noccur when processing invalid view trees.","ref":"Garnish.Renderer.html#validate_tree/1"},{"type":"type","title":"Garnish.Renderer.child_element/0","doc":"","ref":"Garnish.Renderer.html#t:child_element/0"},{"type":"type","title":"Garnish.Renderer.child_tag/0","doc":"","ref":"Garnish.Renderer.html#t:child_tag/0"},{"type":"type","title":"Garnish.Renderer.root_element/0","doc":"","ref":"Garnish.Renderer.html#t:root_element/0"},{"type":"module","title":"Garnish.Renderer.Attributes","doc":"Functions for working with element attributes","ref":"Garnish.Renderer.Attributes.html"},{"type":"function","title":"Garnish.Renderer.Attributes.to_terminal_attribute/1","doc":"","ref":"Garnish.Renderer.Attributes.html#to_terminal_attribute/1"},{"type":"function","title":"Garnish.Renderer.Attributes.to_terminal_color/1","doc":"","ref":"Garnish.Renderer.Attributes.html#to_terminal_color/1"},{"type":"module","title":"Garnish.Renderer.Border","doc":"Primitives for rendering borders","ref":"Garnish.Renderer.Border.html"},{"type":"function","title":"Garnish.Renderer.Border.render/2","doc":"","ref":"Garnish.Renderer.Border.html#render/2"},{"type":"module","title":"Garnish.Renderer.Box","doc":"This defines the internal representation of a rectangular region---a box---for\nrendering, as well as logic for transforming these boxes.\n\nBoxes live on a coordinate plane. The y-axis is inverted so that the y values\nincrease as the box's height grows.\n\n    --------------> x\n    |\n    |    ________\n    |    |      |\n    |    |______|\n    v\n    y\n\nA `Box` struct stores the coordinates for two corners of the box---the\ntop-left and bottom-right corners--from which the remaining attributes\n(height, width, other corners) can be computed.\n\n     _________________\n    |                 |\n    |  A              |\n    |                 |\n    |                 |\n    |                 |\n    |              B  |\n    |_________________|\n\n    A: top-left corner, e.g. (0, 0)\n    B: bottom-right corner, e.g. (10, 10)\n\nFor rendering purposes, the outermost box will typically have a top-left\ncorner (0, 0) and a bottom-right corner (x, y) where x is the number of rows\nand y is the number of columns on the terminal.\n\nThis outermost box can then be subdivided as necessary to render different\nelements of the view.","ref":"Garnish.Renderer.Box.html"},{"type":"function","title":"Garnish.Renderer.Box.bottom_left/1","doc":"","ref":"Garnish.Renderer.Box.html#bottom_left/1"},{"type":"function","title":"Garnish.Renderer.Box.bottom_right/1","doc":"","ref":"Garnish.Renderer.Box.html#bottom_right/1"},{"type":"function","title":"Garnish.Renderer.Box.consume/3","doc":"","ref":"Garnish.Renderer.Box.html#consume/3"},{"type":"function","title":"Garnish.Renderer.Box.contains?/2","doc":"","ref":"Garnish.Renderer.Box.html#contains?/2"},{"type":"function","title":"Garnish.Renderer.Box.from_dimensions/3","doc":"","ref":"Garnish.Renderer.Box.html#from_dimensions/3"},{"type":"function","title":"Garnish.Renderer.Box.head/2","doc":"Given a box, returns a slice of the y axis with `n` rows from the top.","ref":"Garnish.Renderer.Box.html#head/2"},{"type":"function","title":"Garnish.Renderer.Box.height/1","doc":"","ref":"Garnish.Renderer.Box.html#height/1"},{"type":"function","title":"Garnish.Renderer.Box.padded/2","doc":"","ref":"Garnish.Renderer.Box.html#padded/2"},{"type":"function","title":"Garnish.Renderer.Box.positions/1","doc":"","ref":"Garnish.Renderer.Box.html#positions/1"},{"type":"function","title":"Garnish.Renderer.Box.tail/2","doc":"Given a box, returns a slice of the y axis with `n` rows from the bottom.","ref":"Garnish.Renderer.Box.html#tail/2"},{"type":"function","title":"Garnish.Renderer.Box.top_left/1","doc":"","ref":"Garnish.Renderer.Box.html#top_left/1"},{"type":"function","title":"Garnish.Renderer.Box.top_right/1","doc":"","ref":"Garnish.Renderer.Box.html#top_right/1"},{"type":"function","title":"Garnish.Renderer.Box.translate/3","doc":"","ref":"Garnish.Renderer.Box.html#translate/3"},{"type":"function","title":"Garnish.Renderer.Box.width/1","doc":"","ref":"Garnish.Renderer.Box.html#width/1"},{"type":"type","title":"Garnish.Renderer.Box.t/0","doc":"","ref":"Garnish.Renderer.Box.html#t:t/0"},{"type":"module","title":"Garnish.Renderer.Canvas","doc":"A canvas represents a terminal window, a subvision of it for rendering, and a\nsparse mapping of positions to cells.\n\nA `%Canvas{}` struct can be rendered to different output formats. This includes\nthe primary use-case of rendering to the termbox-managed window, but also\nrendering to strings, which is useful for testing.","ref":"Garnish.Renderer.Canvas.html"},{"type":"function","title":"Garnish.Renderer.Canvas.consume/3","doc":"Copies the canvas to a new one with the render box consumed by the given `dx`\nand `dy`.\n\nThe render box is used to indicate the empty, renderable space on the canvas,\nso this might be called with a `dy` of 1 after rendering a line of text. The\nbox is consumed left-to-right and top-to-bottom.","ref":"Garnish.Renderer.Canvas.html#consume/3"},{"type":"function","title":"Garnish.Renderer.Canvas.consume_columns/2","doc":"Creates a new canvas with `n` columns (from the left) consumed.","ref":"Garnish.Renderer.Canvas.html#consume_columns/2"},{"type":"function","title":"Garnish.Renderer.Canvas.consume_rows/2","doc":"Creates a new canvas with `n` rows (from the top) consumed.","ref":"Garnish.Renderer.Canvas.html#consume_rows/2"},{"type":"function","title":"Garnish.Renderer.Canvas.fill_background/1","doc":"","ref":"Garnish.Renderer.Canvas.html#fill_background/1"},{"type":"function","title":"Garnish.Renderer.Canvas.from_dimensions/2","doc":"Creates an empty canvas with the given dimensions.","ref":"Garnish.Renderer.Canvas.html#from_dimensions/2"},{"type":"function","title":"Examples - Garnish.Renderer.Canvas.from_dimensions/2","doc":"iex> Canvas.from_dimensions(10, 20)\n    %Canvas{\n      outer_box: %Garnish.Renderer.Box{\n        top_left: %Garnish.Position{x: 0, y: 0},\n        bottom_right: %Garnish.Position{x: 9, y: 19}\n      },\n      render_box: %Garnish.Renderer.Box{\n        top_left: %Garnish.Position{x: 0, y: 0},\n        bottom_right: %Garnish.Position{x: 9, y: 19}\n      },\n      cells: %{}\n    }","ref":"Garnish.Renderer.Canvas.html#from_dimensions/2-examples"},{"type":"function","title":"Garnish.Renderer.Canvas.merge_cells/2","doc":"Merges a list of cells into the canvas, provided that the cells are located\nwithin the canvas's rendering box. Returns a new canvas with the merged cells.","ref":"Garnish.Renderer.Canvas.html#merge_cells/2"},{"type":"function","title":"Garnish.Renderer.Canvas.padded/2","doc":"Copies the canvas to a new one with the render box padded on each side (top,\nleft, bottom, right) by `size`. Pass a negative size to remove padding.","ref":"Garnish.Renderer.Canvas.html#padded/2"},{"type":"function","title":"Garnish.Renderer.Canvas.put_box/2","doc":"","ref":"Garnish.Renderer.Canvas.html#put_box/2"},{"type":"function","title":"Garnish.Renderer.Canvas.render_to_string/1","doc":"","ref":"Garnish.Renderer.Canvas.html#render_to_string/1"},{"type":"function","title":"Garnish.Renderer.Canvas.render_to_strings/1","doc":"","ref":"Garnish.Renderer.Canvas.html#render_to_strings/1"},{"type":"function","title":"Garnish.Renderer.Canvas.render_to_termbox/2","doc":"","ref":"Garnish.Renderer.Canvas.html#render_to_termbox/2"},{"type":"function","title":"Garnish.Renderer.Canvas.translate/3","doc":"","ref":"Garnish.Renderer.Canvas.html#translate/3"},{"type":"type","title":"Garnish.Renderer.Canvas.t/0","doc":"","ref":"Garnish.Renderer.Canvas.html#t:t/0"},{"type":"module","title":"Garnish.Renderer.Cells","doc":"Functions for working with canvas cells.","ref":"Garnish.Renderer.Cells.html"},{"type":"function","title":"Garnish.Renderer.Cells.background/1","doc":"Computes a cell's background given a standardized attributes map.","ref":"Garnish.Renderer.Cells.html#background/1"},{"type":"function","title":"Garnish.Renderer.Cells.foreground/1","doc":"Computes a cell's foreground given a standardized attributes map.\n\nThe foreground value is computed by taking the color's integer value and the\ninteger values of any styling attributes (e.g., bold, underline) and computing\nthe bitwise OR of all the values.","ref":"Garnish.Renderer.Cells.html#foreground/1"},{"type":"function","title":"Garnish.Renderer.Cells.generator/3","doc":"Given a starting position, orientation and cell template, returns a cell\ngenerator which can be used to iteratively generate a row or column of cells.","ref":"Garnish.Renderer.Cells.html#generator/3"},{"type":"module","title":"Garnish.Renderer.Element","doc":"Represents a renderable element.","ref":"Garnish.Renderer.Element.html"},{"type":"function","title":"Garnish.Renderer.Element.specs/0","doc":"","ref":"Garnish.Renderer.Element.html#specs/0"},{"type":"type","title":"Garnish.Renderer.Element.t/0","doc":"","ref":"Garnish.Renderer.Element.html#t:t/0"},{"type":"module","title":"Garnish.Renderer.Line","doc":"Primitives for rendering lines","ref":"Garnish.Renderer.Line.html"},{"type":"function","title":"Garnish.Renderer.Line.render/6","doc":"","ref":"Garnish.Renderer.Line.html#render/6"},{"type":"function","title":"Garnish.Renderer.Line.render_horizontal/5","doc":"","ref":"Garnish.Renderer.Line.html#render_horizontal/5"},{"type":"function","title":"Garnish.Renderer.Line.render_vertical/5","doc":"","ref":"Garnish.Renderer.Line.html#render_vertical/5"},{"type":"module","title":"Garnish.Renderer.Text","doc":"Primitives for rendering text","ref":"Garnish.Renderer.Text.html"},{"type":"function","title":"Garnish.Renderer.Text.render/4","doc":"","ref":"Garnish.Renderer.Text.html#render/4"},{"type":"function","title":"Garnish.Renderer.Text.render_group/3","doc":"","ref":"Garnish.Renderer.Text.html#render_group/3"},{"type":"behaviour","title":"Garnish.TermInfo","doc":"A behaviour for defining the terminfo sequences a 'terminal'\nmodule should support.","ref":"Garnish.TermInfo.html"},{"type":"callback","title":"Garnish.TermInfo.civis/0","doc":"Make the cursor invisible","ref":"Garnish.TermInfo.html#c:civis/0"},{"type":"callback","title":"Garnish.TermInfo.clear/0","doc":"Clear the screen","ref":"Garnish.TermInfo.html#c:clear/0"},{"type":"callback","title":"Garnish.TermInfo.cnorm/0","doc":"Restore the cursor","ref":"Garnish.TermInfo.html#c:cnorm/0"},{"type":"callback","title":"Garnish.TermInfo.colors/0","doc":"Return the number of colors supported by the terminal","ref":"Garnish.TermInfo.html#c:colors/0"},{"type":"callback","title":"Garnish.TermInfo.cup/2","doc":"Move the cursor to the specified position","ref":"Garnish.TermInfo.html#c:cup/2"},{"type":"callback","title":"Garnish.TermInfo.get_keymap/0","doc":"Returns the keymap for the terminal","ref":"Garnish.TermInfo.html#c:get_keymap/0"},{"type":"function","title":"Garnish.TermInfo.lookup/1","doc":"Look up the terminal module by name, returning nil if not supported.","ref":"Garnish.TermInfo.html#lookup/1"},{"type":"callback","title":"Garnish.TermInfo.rmcup/0","doc":"Restore the main buffer","ref":"Garnish.TermInfo.html#c:rmcup/0"},{"type":"callback","title":"Garnish.TermInfo.rmkx/0","doc":"Restore the terminal mode","ref":"Garnish.TermInfo.html#c:rmkx/0"},{"type":"callback","title":"Garnish.TermInfo.setab/1","doc":"Set the background color","ref":"Garnish.TermInfo.html#c:setab/1"},{"type":"callback","title":"Garnish.TermInfo.setaf/1","doc":"Set the foreground color","ref":"Garnish.TermInfo.html#c:setaf/1"},{"type":"callback","title":"Garnish.TermInfo.sgr0/0","doc":"Clear the graphic attributes","ref":"Garnish.TermInfo.html#c:sgr0/0"},{"type":"callback","title":"Garnish.TermInfo.sgr/1","doc":"Set the graphic attributes","ref":"Garnish.TermInfo.html#c:sgr/1"},{"type":"callback","title":"Garnish.TermInfo.smcup/0","doc":"Save the main buffer and switch to the alternate buffer","ref":"Garnish.TermInfo.html#c:smcup/0"},{"type":"callback","title":"Garnish.TermInfo.smkx/0","doc":"Set the terminal to application mode","ref":"Garnish.TermInfo.html#c:smkx/0"},{"type":"module","title":"Garnish.TermInfo.Linux","doc":"","ref":"Garnish.TermInfo.Linux.html"},{"type":"function","title":"Garnish.TermInfo.Linux.civis/0","doc":"","ref":"Garnish.TermInfo.Linux.html#civis/0"},{"type":"function","title":"Garnish.TermInfo.Linux.clear/0","doc":"","ref":"Garnish.TermInfo.Linux.html#clear/0"},{"type":"function","title":"Garnish.TermInfo.Linux.cnorm/0","doc":"","ref":"Garnish.TermInfo.Linux.html#cnorm/0"},{"type":"function","title":"Garnish.TermInfo.Linux.colors/0","doc":"","ref":"Garnish.TermInfo.Linux.html#colors/0"},{"type":"function","title":"Garnish.TermInfo.Linux.cup/2","doc":"","ref":"Garnish.TermInfo.Linux.html#cup/2"},{"type":"function","title":"Garnish.TermInfo.Linux.get_keymap/0","doc":"","ref":"Garnish.TermInfo.Linux.html#get_keymap/0"},{"type":"function","title":"Garnish.TermInfo.Linux.rmcup/0","doc":"","ref":"Garnish.TermInfo.Linux.html#rmcup/0"},{"type":"function","title":"Garnish.TermInfo.Linux.rmkx/0","doc":"","ref":"Garnish.TermInfo.Linux.html#rmkx/0"},{"type":"function","title":"Garnish.TermInfo.Linux.setab/1","doc":"","ref":"Garnish.TermInfo.Linux.html#setab/1"},{"type":"function","title":"Garnish.TermInfo.Linux.setaf/1","doc":"","ref":"Garnish.TermInfo.Linux.html#setaf/1"},{"type":"function","title":"Garnish.TermInfo.Linux.sgr0/0","doc":"","ref":"Garnish.TermInfo.Linux.html#sgr0/0"},{"type":"function","title":"Garnish.TermInfo.Linux.sgr/1","doc":"","ref":"Garnish.TermInfo.Linux.html#sgr/1"},{"type":"function","title":"Garnish.TermInfo.Linux.smcup/0","doc":"","ref":"Garnish.TermInfo.Linux.html#smcup/0"},{"type":"function","title":"Garnish.TermInfo.Linux.smkx/0","doc":"","ref":"Garnish.TermInfo.Linux.html#smkx/0"},{"type":"module","title":"Garnish.TermInfo.Rxvt","doc":"","ref":"Garnish.TermInfo.Rxvt.html"},{"type":"function","title":"Garnish.TermInfo.Rxvt.civis/0","doc":"","ref":"Garnish.TermInfo.Rxvt.html#civis/0"},{"type":"function","title":"Garnish.TermInfo.Rxvt.clear/0","doc":"","ref":"Garnish.TermInfo.Rxvt.html#clear/0"},{"type":"function","title":"Garnish.TermInfo.Rxvt.cnorm/0","doc":"","ref":"Garnish.TermInfo.Rxvt.html#cnorm/0"},{"type":"function","title":"Garnish.TermInfo.Rxvt.colors/0","doc":"","ref":"Garnish.TermInfo.Rxvt.html#colors/0"},{"type":"function","title":"Garnish.TermInfo.Rxvt.cup/2","doc":"","ref":"Garnish.TermInfo.Rxvt.html#cup/2"},{"type":"function","title":"Garnish.TermInfo.Rxvt.get_keymap/0","doc":"","ref":"Garnish.TermInfo.Rxvt.html#get_keymap/0"},{"type":"function","title":"Garnish.TermInfo.Rxvt.rmcup/0","doc":"","ref":"Garnish.TermInfo.Rxvt.html#rmcup/0"},{"type":"function","title":"Garnish.TermInfo.Rxvt.rmkx/0","doc":"","ref":"Garnish.TermInfo.Rxvt.html#rmkx/0"},{"type":"function","title":"Garnish.TermInfo.Rxvt.setab/1","doc":"","ref":"Garnish.TermInfo.Rxvt.html#setab/1"},{"type":"function","title":"Garnish.TermInfo.Rxvt.setaf/1","doc":"","ref":"Garnish.TermInfo.Rxvt.html#setaf/1"},{"type":"function","title":"Garnish.TermInfo.Rxvt.sgr0/0","doc":"","ref":"Garnish.TermInfo.Rxvt.html#sgr0/0"},{"type":"function","title":"Garnish.TermInfo.Rxvt.sgr/1","doc":"","ref":"Garnish.TermInfo.Rxvt.html#sgr/1"},{"type":"function","title":"Garnish.TermInfo.Rxvt.smcup/0","doc":"","ref":"Garnish.TermInfo.Rxvt.html#smcup/0"},{"type":"function","title":"Garnish.TermInfo.Rxvt.smkx/0","doc":"","ref":"Garnish.TermInfo.Rxvt.html#smkx/0"},{"type":"module","title":"Garnish.TermInfo.Xterm","doc":"","ref":"Garnish.TermInfo.Xterm.html"},{"type":"function","title":"Garnish.TermInfo.Xterm.civis/0","doc":"","ref":"Garnish.TermInfo.Xterm.html#civis/0"},{"type":"function","title":"Garnish.TermInfo.Xterm.clear/0","doc":"","ref":"Garnish.TermInfo.Xterm.html#clear/0"},{"type":"function","title":"Garnish.TermInfo.Xterm.cnorm/0","doc":"","ref":"Garnish.TermInfo.Xterm.html#cnorm/0"},{"type":"function","title":"Garnish.TermInfo.Xterm.colors/0","doc":"","ref":"Garnish.TermInfo.Xterm.html#colors/0"},{"type":"function","title":"Garnish.TermInfo.Xterm.cup/2","doc":"","ref":"Garnish.TermInfo.Xterm.html#cup/2"},{"type":"function","title":"Garnish.TermInfo.Xterm.get_keymap/0","doc":"","ref":"Garnish.TermInfo.Xterm.html#get_keymap/0"},{"type":"function","title":"Garnish.TermInfo.Xterm.rmcup/0","doc":"","ref":"Garnish.TermInfo.Xterm.html#rmcup/0"},{"type":"function","title":"Garnish.TermInfo.Xterm.rmkx/0","doc":"","ref":"Garnish.TermInfo.Xterm.html#rmkx/0"},{"type":"function","title":"Garnish.TermInfo.Xterm.setab/1","doc":"","ref":"Garnish.TermInfo.Xterm.html#setab/1"},{"type":"function","title":"Garnish.TermInfo.Xterm.setaf/1","doc":"","ref":"Garnish.TermInfo.Xterm.html#setaf/1"},{"type":"function","title":"Garnish.TermInfo.Xterm.sgr0/0","doc":"","ref":"Garnish.TermInfo.Xterm.html#sgr0/0"},{"type":"function","title":"Garnish.TermInfo.Xterm.sgr/1","doc":"","ref":"Garnish.TermInfo.Xterm.html#sgr/1"},{"type":"function","title":"Garnish.TermInfo.Xterm.smcup/0","doc":"","ref":"Garnish.TermInfo.Xterm.html#smcup/0"},{"type":"function","title":"Garnish.TermInfo.Xterm.smkx/0","doc":"","ref":"Garnish.TermInfo.Xterm.html#smkx/0"},{"type":"module","title":"Garnish.TermInfo.Xterm256color","doc":"","ref":"Garnish.TermInfo.Xterm256color.html"},{"type":"function","title":"Garnish.TermInfo.Xterm256color.civis/0","doc":"","ref":"Garnish.TermInfo.Xterm256color.html#civis/0"},{"type":"function","title":"Garnish.TermInfo.Xterm256color.clear/0","doc":"","ref":"Garnish.TermInfo.Xterm256color.html#clear/0"},{"type":"function","title":"Garnish.TermInfo.Xterm256color.cnorm/0","doc":"","ref":"Garnish.TermInfo.Xterm256color.html#cnorm/0"},{"type":"function","title":"Garnish.TermInfo.Xterm256color.colors/0","doc":"","ref":"Garnish.TermInfo.Xterm256color.html#colors/0"},{"type":"function","title":"Garnish.TermInfo.Xterm256color.cup/2","doc":"","ref":"Garnish.TermInfo.Xterm256color.html#cup/2"},{"type":"function","title":"Garnish.TermInfo.Xterm256color.get_keymap/0","doc":"","ref":"Garnish.TermInfo.Xterm256color.html#get_keymap/0"},{"type":"function","title":"Garnish.TermInfo.Xterm256color.rmcup/0","doc":"","ref":"Garnish.TermInfo.Xterm256color.html#rmcup/0"},{"type":"function","title":"Garnish.TermInfo.Xterm256color.rmkx/0","doc":"","ref":"Garnish.TermInfo.Xterm256color.html#rmkx/0"},{"type":"function","title":"Garnish.TermInfo.Xterm256color.setab/1","doc":"","ref":"Garnish.TermInfo.Xterm256color.html#setab/1"},{"type":"function","title":"Garnish.TermInfo.Xterm256color.setaf/1","doc":"","ref":"Garnish.TermInfo.Xterm256color.html#setaf/1"},{"type":"function","title":"Garnish.TermInfo.Xterm256color.sgr0/0","doc":"","ref":"Garnish.TermInfo.Xterm256color.html#sgr0/0"},{"type":"function","title":"Garnish.TermInfo.Xterm256color.sgr/1","doc":"","ref":"Garnish.TermInfo.Xterm256color.html#sgr/1"},{"type":"function","title":"Garnish.TermInfo.Xterm256color.smcup/0","doc":"","ref":"Garnish.TermInfo.Xterm256color.html#smcup/0"},{"type":"function","title":"Garnish.TermInfo.Xterm256color.smkx/0","doc":"","ref":"Garnish.TermInfo.Xterm256color.html#smkx/0"},{"type":"module","title":"Garnish.View","doc":"In Garnish, a view is simply a tree of elements. Each element in the tree\nholds an attributes map and a list of zero or more child nodes. Visually, it\nlooks like something this:\n\n    %Element{\n      tag: :view,\n      attributes: %{},\n      children: [\n        %Element{\n          tag: :row,\n          attributes: %{},\n          children: [\n            %Element{tag: :column, attributes: %{size: 4}, children: []},\n            %Element{tag: :column, attributes: %{size: 4}, children: []},\n            %Element{tag: :column, attributes: %{size: 4}, children: []}\n          ]\n        }\n      ]\n    }","ref":"Garnish.View.html"},{"type":"module","title":"View DSL - Garnish.View","doc":"Because it's a bit tedious to define views like that, Garnish provides a\nDSL to define them without all the boilerplate.\n\nNow we can turn the above into this:\n\n    view do\n      row do\n        column(size: 4)\n        column(size: 4)\n        column(size: 4)\n      end\n    end\n\nWhile the syntax is more compact, the end result is exactly the same. This\nexpression produces the exact same `%Element{}` struct as defined above.\n\nTo use the DSL like this, we need to import all the functions:\n\n    import Garnish.View\n\nAlternatively, import just the ones you need:\n\n    import Garnish.View, only: [view: 0, row: 0, column: 1]","ref":"Garnish.View.html#module-view-dsl"},{"type":"module","title":"Forms - Garnish.View","doc":"All of the possible forms are enumerated below.\n\nElement with tag `foo`:\n\n    foo()\n\nElement with tag `foo` and attributes:\n\n    foo(size: 42)\n\nElement with tag `foo` and children as list:\n\n    foo([\n      bar()\n    ])\n\nElement with tag `foo` and children as block:\n\n    foo do\n      bar()\n    end\n\nElement with tag `foo`, attributes, and children as list:\n\n    foo(\n      [size: 42],\n      [bar()]\n    )\n\nElement with tag `foo`, attributes, and children as block:\n\n    foo size: 42 do\n      bar()\n    end","ref":"Garnish.View.html#module-forms"},{"type":"module","title":"Empty Elements - Garnish.View","doc":"Similar to so-called \"empty\" HTML elements such as ` `, Garnish also\nhas elements for which passing content doesn't make sense. For example, the\nleaf node `text` stores its content in its attributes and cannot have any\nchild elements of its own.\n\nIn such cases, the block and list forms are unsupported.","ref":"Garnish.View.html#module-empty-elements"},{"type":"module","title":"Validation - Garnish.View","doc":"While some errors---such as passing children to empty elements---are prevented\nby the DSL, it's still possible (for now, at least) to build\nsemantically-invalid element trees using the DSL. This means that the elements\nare being used in a way that doesn't make sense to the renderer.\n\nIn order to prevent cryptic rendering errors, the renderer first validates the\nelement tree it's given and rejects the whole thing if the structure is\nunsupported. It currently checks the following things:\n\n* The top-level element passed to the renderer must have the `:view` tag.\n* A parent element may only have child elements that have one of the\n  supported child tags for the parent element.\n* An element must define all of its required attributes and may not define any\n  unknown attributes.\n\nThe last two rules are based on the element's specification in\n`Garnish.Renderer.Element`.","ref":"Garnish.View.html#module-validation"},{"type":"macro","title":"Garnish.View.bar/0","doc":"Defines an element with the `:bar` tag.","ref":"Garnish.View.html#bar/0"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.bar/0","doc":"* label","ref":"Garnish.View.html#bar/0-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.bar/0","doc":"Empty element:\n\n    bar()\n\nWith a block:\n\n    bar do\n      # ...child elements...\n    end","ref":"Garnish.View.html#bar/0-examples"},{"type":"macro","title":"Garnish.View.bar/1","doc":"Defines an element with the `:bar` tag and either:\n\n* given attributes and an optional block\n* a list of child elements","ref":"Garnish.View.html#bar/1"},{"type":"macro","title":"Attributes - Garnish.View.bar/1","doc":"None","ref":"Garnish.View.html#bar/1-attributes"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.bar/1","doc":"* label","ref":"Garnish.View.html#bar/1-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.bar/1","doc":"Passing attributes:\n\n    bar(key: value)\n\nPassing attributes and a block:\n\n    bar(key: value) do\n      # ...child elements...\n    end\n\nPassing list of children:\n\n    bar([elem1, elem2])","ref":"Garnish.View.html#bar/1-examples"},{"type":"macro","title":"Garnish.View.bar/2","doc":"Defines an element with the `:bar` tag and the given attributes and\nchild elements.","ref":"Garnish.View.html#bar/2"},{"type":"macro","title":"Attributes - Garnish.View.bar/2","doc":"None","ref":"Garnish.View.html#bar/2-attributes"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.bar/2","doc":"* label","ref":"Garnish.View.html#bar/2-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.bar/2","doc":"bar([key: value], [elem1, elem2])","ref":"Garnish.View.html#bar/2-examples"},{"type":"macro","title":"Garnish.View.canvas/0","doc":"Defines an element with the `:canvas` tag.","ref":"Garnish.View.html#canvas/0"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.canvas/0","doc":"* canvas_cell","ref":"Garnish.View.html#canvas/0-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.canvas/0","doc":"Empty element:\n\n    canvas()\n\nWith a block:\n\n    canvas do\n      # ...child elements...\n    end","ref":"Garnish.View.html#canvas/0-examples"},{"type":"macro","title":"Garnish.View.canvas/1","doc":"Defines an element with the `:canvas` tag and either:\n\n* given attributes and an optional block\n* a list of child elements","ref":"Garnish.View.html#canvas/1"},{"type":"macro","title":"Attributes - Garnish.View.canvas/1","doc":"* `height` (required) - Integer representing the canvas height\n* `width` (required) - Integer representing the canvas width","ref":"Garnish.View.html#canvas/1-attributes"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.canvas/1","doc":"* canvas_cell","ref":"Garnish.View.html#canvas/1-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.canvas/1","doc":"Passing attributes:\n\n    canvas(key: value)\n\nPassing attributes and a block:\n\n    canvas(key: value) do\n      # ...child elements...\n    end\n\nPassing list of children:\n\n    canvas([elem1, elem2])","ref":"Garnish.View.html#canvas/1-examples"},{"type":"macro","title":"Garnish.View.canvas/2","doc":"Defines an element with the `:canvas` tag and the given attributes and\nchild elements.","ref":"Garnish.View.html#canvas/2"},{"type":"macro","title":"Attributes - Garnish.View.canvas/2","doc":"* `height` (required) - Integer representing the canvas height\n* `width` (required) - Integer representing the canvas width","ref":"Garnish.View.html#canvas/2-attributes"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.canvas/2","doc":"* canvas_cell","ref":"Garnish.View.html#canvas/2-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.canvas/2","doc":"canvas([key: value], [elem1, elem2])","ref":"Garnish.View.html#canvas/2-examples"},{"type":"macro","title":"Garnish.View.canvas_cell/0","doc":"Defines an element with the `:canvas_cell` tag.","ref":"Garnish.View.html#canvas_cell/0"},{"type":"macro","title":"Examples - Garnish.View.canvas_cell/0","doc":"Empty element:\n\n    canvas_cell()","ref":"Garnish.View.html#canvas_cell/0-examples"},{"type":"macro","title":"Garnish.View.canvas_cell/1","doc":"Defines an element with the `:canvas_cell` tag and the given attributes.","ref":"Garnish.View.html#canvas_cell/1"},{"type":"macro","title":"Attributes - Garnish.View.canvas_cell/1","doc":"* `x` (required) - Integer representing the cell's column (zero-indexed)\n* `y` (required) - Integer representing the cell's row (zero-indexed)\n* `color` (optional) - Constant representing color to use for foreground\n* `char` (optional) - Single character to render within this cell\n* `background` (optional) - Constant representing color to use for background\n* `attributes` (optional) - Constant representing style attributes to apply","ref":"Garnish.View.html#canvas_cell/1-attributes"},{"type":"macro","title":"Examples - Garnish.View.canvas_cell/1","doc":"canvas_cell(key: value)","ref":"Garnish.View.html#canvas_cell/1-examples"},{"type":"macro","title":"Garnish.View.chart/0","doc":"Defines an element with the `:chart` tag.","ref":"Garnish.View.html#chart/0"},{"type":"macro","title":"Examples - Garnish.View.chart/0","doc":"Empty element:\n\n    chart()","ref":"Garnish.View.html#chart/0-examples"},{"type":"macro","title":"Garnish.View.chart/1","doc":"Defines an element with the `:chart` tag and the given attributes.","ref":"Garnish.View.html#chart/1"},{"type":"macro","title":"Attributes - Garnish.View.chart/1","doc":"* `series` (required) - List of float or integer values representing the series\n* `type` (required) - Type of chart to plot. Currently only `:line` is supported\n* `height` (optional) - Height of the chart in rows","ref":"Garnish.View.html#chart/1-attributes"},{"type":"macro","title":"Examples - Garnish.View.chart/1","doc":"chart(key: value)","ref":"Garnish.View.html#chart/1-examples"},{"type":"macro","title":"Garnish.View.column/0","doc":"Defines an element with the `:column` tag.","ref":"Garnish.View.html#column/0"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.column/0","doc":"* canvas\n* chart\n* label\n* panel\n* row\n* sparkline\n* table\n* tree\n* viewport\n* progress_bar","ref":"Garnish.View.html#column/0-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.column/0","doc":"Empty element:\n\n    column()\n\nWith a block:\n\n    column do\n      # ...child elements...\n    end","ref":"Garnish.View.html#column/0-examples"},{"type":"macro","title":"Garnish.View.column/1","doc":"Defines an element with the `:column` tag and either:\n\n* given attributes and an optional block\n* a list of child elements","ref":"Garnish.View.html#column/1"},{"type":"macro","title":"Attributes - Garnish.View.column/1","doc":"* `size` (required) - Number of units on the grid that the column should occupy","ref":"Garnish.View.html#column/1-attributes"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.column/1","doc":"* canvas\n* chart\n* label\n* panel\n* row\n* sparkline\n* table\n* tree\n* viewport\n* progress_bar","ref":"Garnish.View.html#column/1-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.column/1","doc":"Passing attributes:\n\n    column(key: value)\n\nPassing attributes and a block:\n\n    column(key: value) do\n      # ...child elements...\n    end\n\nPassing list of children:\n\n    column([elem1, elem2])","ref":"Garnish.View.html#column/1-examples"},{"type":"macro","title":"Garnish.View.column/2","doc":"Defines an element with the `:column` tag and the given attributes and\nchild elements.","ref":"Garnish.View.html#column/2"},{"type":"macro","title":"Attributes - Garnish.View.column/2","doc":"* `size` (required) - Number of units on the grid that the column should occupy","ref":"Garnish.View.html#column/2-attributes"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.column/2","doc":"* canvas\n* chart\n* label\n* panel\n* row\n* sparkline\n* table\n* tree\n* viewport\n* progress_bar","ref":"Garnish.View.html#column/2-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.column/2","doc":"column([key: value], [elem1, elem2])","ref":"Garnish.View.html#column/2-examples"},{"type":"function","title":"Garnish.View.element/2","doc":"","ref":"Garnish.View.html#element/2"},{"type":"function","title":"Garnish.View.element/3","doc":"","ref":"Garnish.View.html#element/3"},{"type":"macro","title":"Garnish.View.label/0","doc":"Defines an element with the `:label` tag.","ref":"Garnish.View.html#label/0"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.label/0","doc":"* text","ref":"Garnish.View.html#label/0-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.label/0","doc":"Empty element:\n\n    label()\n\nWith a block:\n\n    label do\n      # ...child elements...\n    end","ref":"Garnish.View.html#label/0-examples"},{"type":"macro","title":"Garnish.View.label/1","doc":"Defines an element with the `:label` tag and either:\n\n* given attributes and an optional block\n* a list of child elements","ref":"Garnish.View.html#label/1"},{"type":"macro","title":"Attributes - Garnish.View.label/1","doc":"* `content` (optional) - Binary containing the text content to be displayed\n* `color` (optional) - Constant representing color to use for foreground\n* `background` (optional) - Constant representing color to use for background\n* `attributes` (optional) - Constant representing style attributes to apply\n* `wrap` (optional) - Boolean indicating whether or not to wrap lines to fit available space","ref":"Garnish.View.html#label/1-attributes"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.label/1","doc":"* text","ref":"Garnish.View.html#label/1-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.label/1","doc":"Passing attributes:\n\n    label(key: value)\n\nPassing attributes and a block:\n\n    label(key: value) do\n      # ...child elements...\n    end\n\nPassing list of children:\n\n    label([elem1, elem2])","ref":"Garnish.View.html#label/1-examples"},{"type":"macro","title":"Garnish.View.label/2","doc":"Defines an element with the `:label` tag and the given attributes and\nchild elements.","ref":"Garnish.View.html#label/2"},{"type":"macro","title":"Attributes - Garnish.View.label/2","doc":"* `content` (optional) - Binary containing the text content to be displayed\n* `color` (optional) - Constant representing color to use for foreground\n* `background` (optional) - Constant representing color to use for background\n* `attributes` (optional) - Constant representing style attributes to apply\n* `wrap` (optional) - Boolean indicating whether or not to wrap lines to fit available space","ref":"Garnish.View.html#label/2-attributes"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.label/2","doc":"* text","ref":"Garnish.View.html#label/2-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.label/2","doc":"label([key: value], [elem1, elem2])","ref":"Garnish.View.html#label/2-examples"},{"type":"macro","title":"Garnish.View.overlay/0","doc":"Defines an element with the `:overlay` tag.","ref":"Garnish.View.html#overlay/0"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.overlay/0","doc":"* canvas\n* chart\n* label\n* panel\n* row\n* sparkline\n* table\n* tree\n* viewport\n* progress_bar","ref":"Garnish.View.html#overlay/0-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.overlay/0","doc":"Empty element:\n\n    overlay()\n\nWith a block:\n\n    overlay do\n      # ...child elements...\n    end","ref":"Garnish.View.html#overlay/0-examples"},{"type":"macro","title":"Garnish.View.overlay/1","doc":"Defines an element with the `:overlay` tag and either:\n\n* given attributes and an optional block\n* a list of child elements","ref":"Garnish.View.html#overlay/1"},{"type":"macro","title":"Attributes - Garnish.View.overlay/1","doc":"* `padding` (optional) - Integer number of units of padding","ref":"Garnish.View.html#overlay/1-attributes"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.overlay/1","doc":"* canvas\n* chart\n* label\n* panel\n* row\n* sparkline\n* table\n* tree\n* viewport\n* progress_bar","ref":"Garnish.View.html#overlay/1-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.overlay/1","doc":"Passing attributes:\n\n    overlay(key: value)\n\nPassing attributes and a block:\n\n    overlay(key: value) do\n      # ...child elements...\n    end\n\nPassing list of children:\n\n    overlay([elem1, elem2])","ref":"Garnish.View.html#overlay/1-examples"},{"type":"macro","title":"Garnish.View.overlay/2","doc":"Defines an element with the `:overlay` tag and the given attributes and\nchild elements.","ref":"Garnish.View.html#overlay/2"},{"type":"macro","title":"Attributes - Garnish.View.overlay/2","doc":"* `padding` (optional) - Integer number of units of padding","ref":"Garnish.View.html#overlay/2-attributes"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.overlay/2","doc":"* canvas\n* chart\n* label\n* panel\n* row\n* sparkline\n* table\n* tree\n* viewport\n* progress_bar","ref":"Garnish.View.html#overlay/2-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.overlay/2","doc":"overlay([key: value], [elem1, elem2])","ref":"Garnish.View.html#overlay/2-examples"},{"type":"macro","title":"Garnish.View.panel/0","doc":"Defines an element with the `:panel` tag.","ref":"Garnish.View.html#panel/0"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.panel/0","doc":"* canvas\n* chart\n* label\n* panel\n* row\n* sparkline\n* table\n* tree\n* viewport\n* progress_bar","ref":"Garnish.View.html#panel/0-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.panel/0","doc":"Empty element:\n\n    panel()\n\nWith a block:\n\n    panel do\n      # ...child elements...\n    end","ref":"Garnish.View.html#panel/0-examples"},{"type":"macro","title":"Garnish.View.panel/1","doc":"Defines an element with the `:panel` tag and either:\n\n* given attributes and an optional block\n* a list of child elements","ref":"Garnish.View.html#panel/1"},{"type":"macro","title":"Attributes - Garnish.View.panel/1","doc":"* `color` (optional) - Color of title\n* `background` (optional) - Background of title\n* `attributes` (optional) - Attributes for the title\n* `padding` (optional) - Integer providing inner padding to use when rendering child elements\n* `height` (optional) - Height of the table in rows or `:fill` to fill the parent container's box\n* `title` (optional) - Binary containing the title for the panel\n* `border` (optional) - Attributes for the border","ref":"Garnish.View.html#panel/1-attributes"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.panel/1","doc":"* canvas\n* chart\n* label\n* panel\n* row\n* sparkline\n* table\n* tree\n* viewport\n* progress_bar","ref":"Garnish.View.html#panel/1-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.panel/1","doc":"Passing attributes:\n\n    panel(key: value)\n\nPassing attributes and a block:\n\n    panel(key: value) do\n      # ...child elements...\n    end\n\nPassing list of children:\n\n    panel([elem1, elem2])","ref":"Garnish.View.html#panel/1-examples"},{"type":"macro","title":"Garnish.View.panel/2","doc":"Defines an element with the `:panel` tag and the given attributes and\nchild elements.","ref":"Garnish.View.html#panel/2"},{"type":"macro","title":"Attributes - Garnish.View.panel/2","doc":"* `color` (optional) - Color of title\n* `background` (optional) - Background of title\n* `attributes` (optional) - Attributes for the title\n* `padding` (optional) - Integer providing inner padding to use when rendering child elements\n* `height` (optional) - Height of the table in rows or `:fill` to fill the parent container's box\n* `title` (optional) - Binary containing the title for the panel\n* `border` (optional) - Attributes for the border","ref":"Garnish.View.html#panel/2-attributes"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.panel/2","doc":"* canvas\n* chart\n* label\n* panel\n* row\n* sparkline\n* table\n* tree\n* viewport\n* progress_bar","ref":"Garnish.View.html#panel/2-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.panel/2","doc":"panel([key: value], [elem1, elem2])","ref":"Garnish.View.html#panel/2-examples"},{"type":"macro","title":"Garnish.View.progress_bar/0","doc":"Defines an element with the `:progress_bar` tag.","ref":"Garnish.View.html#progress_bar/0"},{"type":"macro","title":"Examples - Garnish.View.progress_bar/0","doc":"Empty element:\n\n    progress_bar()","ref":"Garnish.View.html#progress_bar/0-examples"},{"type":"macro","title":"Garnish.View.progress_bar/1","doc":"Defines an element with the `:progress_bar` tag and the given attributes.","ref":"Garnish.View.html#progress_bar/1"},{"type":"macro","title":"Attributes - Garnish.View.progress_bar/1","doc":"* `percentage` (required) - The actual percentage\n* `text_position` (optional) - Where to put the text showing the percentage, `:none`, `:left` or `:right`. Defaults to `:right`\n* `on_color` (optional) - The main color of the bar\n* `off_color` (optional) - The background color of the bar\n* `text_color` (optional) - The color of the percentage text","ref":"Garnish.View.html#progress_bar/1-attributes"},{"type":"macro","title":"Examples - Garnish.View.progress_bar/1","doc":"progress_bar(key: value)","ref":"Garnish.View.html#progress_bar/1-examples"},{"type":"macro","title":"Garnish.View.row/0","doc":"Defines an element with the `:row` tag.","ref":"Garnish.View.html#row/0"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.row/0","doc":"* column","ref":"Garnish.View.html#row/0-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.row/0","doc":"Empty element:\n\n    row()\n\nWith a block:\n\n    row do\n      # ...child elements...\n    end","ref":"Garnish.View.html#row/0-examples"},{"type":"macro","title":"Garnish.View.row/1","doc":"Defines an element with the `:row` tag and either:\n\n* given attributes and an optional block\n* a list of child elements","ref":"Garnish.View.html#row/1"},{"type":"macro","title":"Attributes - Garnish.View.row/1","doc":"None","ref":"Garnish.View.html#row/1-attributes"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.row/1","doc":"* column","ref":"Garnish.View.html#row/1-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.row/1","doc":"Passing attributes:\n\n    row(key: value)\n\nPassing attributes and a block:\n\n    row(key: value) do\n      # ...child elements...\n    end\n\nPassing list of children:\n\n    row([elem1, elem2])","ref":"Garnish.View.html#row/1-examples"},{"type":"macro","title":"Garnish.View.row/2","doc":"Defines an element with the `:row` tag and the given attributes and\nchild elements.","ref":"Garnish.View.html#row/2"},{"type":"macro","title":"Attributes - Garnish.View.row/2","doc":"None","ref":"Garnish.View.html#row/2-attributes"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.row/2","doc":"* column","ref":"Garnish.View.html#row/2-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.row/2","doc":"row([key: value], [elem1, elem2])","ref":"Garnish.View.html#row/2-examples"},{"type":"macro","title":"Garnish.View.sparkline/0","doc":"Defines an element with the `:sparkline` tag.","ref":"Garnish.View.html#sparkline/0"},{"type":"macro","title":"Examples - Garnish.View.sparkline/0","doc":"Empty element:\n\n    sparkline()","ref":"Garnish.View.html#sparkline/0-examples"},{"type":"macro","title":"Garnish.View.sparkline/1","doc":"Defines an element with the `:sparkline` tag and the given attributes.","ref":"Garnish.View.html#sparkline/1"},{"type":"macro","title":"Attributes - Garnish.View.sparkline/1","doc":"* `series` (required) - List of float or integer values representing the series","ref":"Garnish.View.html#sparkline/1-attributes"},{"type":"macro","title":"Examples - Garnish.View.sparkline/1","doc":"sparkline(key: value)","ref":"Garnish.View.html#sparkline/1-examples"},{"type":"macro","title":"Garnish.View.table/0","doc":"Defines an element with the `:table` tag.","ref":"Garnish.View.html#table/0"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.table/0","doc":"* table_row","ref":"Garnish.View.html#table/0-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.table/0","doc":"Empty element:\n\n    table()\n\nWith a block:\n\n    table do\n      # ...child elements...\n    end","ref":"Garnish.View.html#table/0-examples"},{"type":"macro","title":"Garnish.View.table/1","doc":"Defines an element with the `:table` tag and either:\n\n* given attributes and an optional block\n* a list of child elements","ref":"Garnish.View.html#table/1"},{"type":"macro","title":"Attributes - Garnish.View.table/1","doc":"None","ref":"Garnish.View.html#table/1-attributes"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.table/1","doc":"* table_row","ref":"Garnish.View.html#table/1-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.table/1","doc":"Passing attributes:\n\n    table(key: value)\n\nPassing attributes and a block:\n\n    table(key: value) do\n      # ...child elements...\n    end\n\nPassing list of children:\n\n    table([elem1, elem2])","ref":"Garnish.View.html#table/1-examples"},{"type":"macro","title":"Garnish.View.table/2","doc":"Defines an element with the `:table` tag and the given attributes and\nchild elements.","ref":"Garnish.View.html#table/2"},{"type":"macro","title":"Attributes - Garnish.View.table/2","doc":"None","ref":"Garnish.View.html#table/2-attributes"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.table/2","doc":"* table_row","ref":"Garnish.View.html#table/2-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.table/2","doc":"table([key: value], [elem1, elem2])","ref":"Garnish.View.html#table/2-examples"},{"type":"macro","title":"Garnish.View.table_cell/0","doc":"Defines an element with the `:table_cell` tag.","ref":"Garnish.View.html#table_cell/0"},{"type":"macro","title":"Examples - Garnish.View.table_cell/0","doc":"Empty element:\n\n    table_cell()","ref":"Garnish.View.html#table_cell/0-examples"},{"type":"macro","title":"Garnish.View.table_cell/1","doc":"Defines an element with the `:table_cell` tag and the given attributes.","ref":"Garnish.View.html#table_cell/1"},{"type":"macro","title":"Attributes - Garnish.View.table_cell/1","doc":"* `content` (required) - Binary containing the text content to be displayed\n* `color` (optional) - Constant representing color to use for foreground\n* `background` (optional) - Constant representing color to use for background\n* `attributes` (optional) - Constant representing style attributes to apply","ref":"Garnish.View.html#table_cell/1-attributes"},{"type":"macro","title":"Examples - Garnish.View.table_cell/1","doc":"table_cell(key: value)","ref":"Garnish.View.html#table_cell/1-examples"},{"type":"macro","title":"Garnish.View.table_row/0","doc":"Defines an element with the `:table_row` tag.","ref":"Garnish.View.html#table_row/0"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.table_row/0","doc":"* table_cell","ref":"Garnish.View.html#table_row/0-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.table_row/0","doc":"Empty element:\n\n    table_row()\n\nWith a block:\n\n    table_row do\n      # ...child elements...\n    end","ref":"Garnish.View.html#table_row/0-examples"},{"type":"macro","title":"Garnish.View.table_row/1","doc":"Defines an element with the `:table_row` tag and either:\n\n* given attributes and an optional block\n* a list of child elements","ref":"Garnish.View.html#table_row/1"},{"type":"macro","title":"Attributes - Garnish.View.table_row/1","doc":"* `color` (optional) - Constant representing color to use for foreground\n* `background` (optional) - Constant representing color to use for background\n* `attributes` (optional) - Constant representing style attributes to apply","ref":"Garnish.View.html#table_row/1-attributes"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.table_row/1","doc":"* table_cell","ref":"Garnish.View.html#table_row/1-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.table_row/1","doc":"Passing attributes:\n\n    table_row(key: value)\n\nPassing attributes and a block:\n\n    table_row(key: value) do\n      # ...child elements...\n    end\n\nPassing list of children:\n\n    table_row([elem1, elem2])","ref":"Garnish.View.html#table_row/1-examples"},{"type":"macro","title":"Garnish.View.table_row/2","doc":"Defines an element with the `:table_row` tag and the given attributes and\nchild elements.","ref":"Garnish.View.html#table_row/2"},{"type":"macro","title":"Attributes - Garnish.View.table_row/2","doc":"* `color` (optional) - Constant representing color to use for foreground\n* `background` (optional) - Constant representing color to use for background\n* `attributes` (optional) - Constant representing style attributes to apply","ref":"Garnish.View.html#table_row/2-attributes"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.table_row/2","doc":"* table_cell","ref":"Garnish.View.html#table_row/2-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.table_row/2","doc":"table_row([key: value], [elem1, elem2])","ref":"Garnish.View.html#table_row/2-examples"},{"type":"macro","title":"Garnish.View.text/0","doc":"Defines an element with the `:text` tag.","ref":"Garnish.View.html#text/0"},{"type":"macro","title":"Examples - Garnish.View.text/0","doc":"Empty element:\n\n    text()","ref":"Garnish.View.html#text/0-examples"},{"type":"macro","title":"Garnish.View.text/1","doc":"Defines an element with the `:text` tag and the given attributes.","ref":"Garnish.View.html#text/1"},{"type":"macro","title":"Attributes - Garnish.View.text/1","doc":"* `content` (required) - Binary containing the text content to be displayed\n* `color` (optional) - Constant representing color to use for foreground\n* `background` (optional) - Constant representing color to use for background\n* `attributes` (optional) - Constant representing style attributes to apply","ref":"Garnish.View.html#text/1-attributes"},{"type":"macro","title":"Examples - Garnish.View.text/1","doc":"text(key: value)","ref":"Garnish.View.html#text/1-examples"},{"type":"macro","title":"Garnish.View.tree/0","doc":"Defines an element with the `:tree` tag.","ref":"Garnish.View.html#tree/0"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.tree/0","doc":"* tree_node","ref":"Garnish.View.html#tree/0-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.tree/0","doc":"Empty element:\n\n    tree()\n\nWith a block:\n\n    tree do\n      # ...child elements...\n    end","ref":"Garnish.View.html#tree/0-examples"},{"type":"macro","title":"Garnish.View.tree/1","doc":"Defines an element with the `:tree` tag and either:\n\n* given attributes and an optional block\n* a list of child elements","ref":"Garnish.View.html#tree/1"},{"type":"macro","title":"Attributes - Garnish.View.tree/1","doc":"None","ref":"Garnish.View.html#tree/1-attributes"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.tree/1","doc":"* tree_node","ref":"Garnish.View.html#tree/1-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.tree/1","doc":"Passing attributes:\n\n    tree(key: value)\n\nPassing attributes and a block:\n\n    tree(key: value) do\n      # ...child elements...\n    end\n\nPassing list of children:\n\n    tree([elem1, elem2])","ref":"Garnish.View.html#tree/1-examples"},{"type":"macro","title":"Garnish.View.tree/2","doc":"Defines an element with the `:tree` tag and the given attributes and\nchild elements.","ref":"Garnish.View.html#tree/2"},{"type":"macro","title":"Attributes - Garnish.View.tree/2","doc":"None","ref":"Garnish.View.html#tree/2-attributes"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.tree/2","doc":"* tree_node","ref":"Garnish.View.html#tree/2-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.tree/2","doc":"tree([key: value], [elem1, elem2])","ref":"Garnish.View.html#tree/2-examples"},{"type":"macro","title":"Garnish.View.tree_node/0","doc":"Defines an element with the `:tree_node` tag.","ref":"Garnish.View.html#tree_node/0"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.tree_node/0","doc":"* tree_node","ref":"Garnish.View.html#tree_node/0-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.tree_node/0","doc":"Empty element:\n\n    tree_node()\n\nWith a block:\n\n    tree_node do\n      # ...child elements...\n    end","ref":"Garnish.View.html#tree_node/0-examples"},{"type":"macro","title":"Garnish.View.tree_node/1","doc":"Defines an element with the `:tree_node` tag and either:\n\n* given attributes and an optional block\n* a list of child elements","ref":"Garnish.View.html#tree_node/1"},{"type":"macro","title":"Attributes - Garnish.View.tree_node/1","doc":"* `content` (required) - Binary label for the node\n* `color` (optional) - Constant representing color to use for foreground\n* `background` (optional) - Constant representing color to use for background\n* `attributes` (optional) - Constant representing style attributes to apply","ref":"Garnish.View.html#tree_node/1-attributes"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.tree_node/1","doc":"* tree_node","ref":"Garnish.View.html#tree_node/1-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.tree_node/1","doc":"Passing attributes:\n\n    tree_node(key: value)\n\nPassing attributes and a block:\n\n    tree_node(key: value) do\n      # ...child elements...\n    end\n\nPassing list of children:\n\n    tree_node([elem1, elem2])","ref":"Garnish.View.html#tree_node/1-examples"},{"type":"macro","title":"Garnish.View.tree_node/2","doc":"Defines an element with the `:tree_node` tag and the given attributes and\nchild elements.","ref":"Garnish.View.html#tree_node/2"},{"type":"macro","title":"Attributes - Garnish.View.tree_node/2","doc":"* `content` (required) - Binary label for the node\n* `color` (optional) - Constant representing color to use for foreground\n* `background` (optional) - Constant representing color to use for background\n* `attributes` (optional) - Constant representing style attributes to apply","ref":"Garnish.View.html#tree_node/2-attributes"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.tree_node/2","doc":"* tree_node","ref":"Garnish.View.html#tree_node/2-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.tree_node/2","doc":"tree_node([key: value], [elem1, elem2])","ref":"Garnish.View.html#tree_node/2-examples"},{"type":"macro","title":"Garnish.View.view/0","doc":"Defines an element with the `:view` tag.","ref":"Garnish.View.html#view/0"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.view/0","doc":"* overlay\n* canvas\n* chart\n* label\n* panel\n* row\n* sparkline\n* table\n* tree\n* viewport\n* progress_bar","ref":"Garnish.View.html#view/0-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.view/0","doc":"Empty element:\n\n    view()\n\nWith a block:\n\n    view do\n      # ...child elements...\n    end","ref":"Garnish.View.html#view/0-examples"},{"type":"macro","title":"Garnish.View.view/1","doc":"Defines an element with the `:view` tag and either:\n\n* given attributes and an optional block\n* a list of child elements","ref":"Garnish.View.html#view/1"},{"type":"macro","title":"Attributes - Garnish.View.view/1","doc":"* `top_bar` (optional) - A `:bar` element to occupy the view's first row\n* `bottom_bar` (optional) - A `:bar` element to occupy the view's last row","ref":"Garnish.View.html#view/1-attributes"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.view/1","doc":"* overlay\n* canvas\n* chart\n* label\n* panel\n* row\n* sparkline\n* table\n* tree\n* viewport\n* progress_bar","ref":"Garnish.View.html#view/1-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.view/1","doc":"Passing attributes:\n\n    view(key: value)\n\nPassing attributes and a block:\n\n    view(key: value) do\n      # ...child elements...\n    end\n\nPassing list of children:\n\n    view([elem1, elem2])","ref":"Garnish.View.html#view/1-examples"},{"type":"macro","title":"Garnish.View.view/2","doc":"Defines an element with the `:view` tag and the given attributes and\nchild elements.","ref":"Garnish.View.html#view/2"},{"type":"macro","title":"Attributes - Garnish.View.view/2","doc":"* `top_bar` (optional) - A `:bar` element to occupy the view's first row\n* `bottom_bar` (optional) - A `:bar` element to occupy the view's last row","ref":"Garnish.View.html#view/2-attributes"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.view/2","doc":"* overlay\n* canvas\n* chart\n* label\n* panel\n* row\n* sparkline\n* table\n* tree\n* viewport\n* progress_bar","ref":"Garnish.View.html#view/2-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.view/2","doc":"view([key: value], [elem1, elem2])","ref":"Garnish.View.html#view/2-examples"},{"type":"macro","title":"Garnish.View.viewport/0","doc":"Defines an element with the `:viewport` tag.","ref":"Garnish.View.html#viewport/0"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.viewport/0","doc":"* canvas\n* chart\n* label\n* panel\n* row\n* sparkline\n* table\n* tree\n* viewport\n* progress_bar","ref":"Garnish.View.html#viewport/0-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.viewport/0","doc":"Empty element:\n\n    viewport()\n\nWith a block:\n\n    viewport do\n      # ...child elements...\n    end","ref":"Garnish.View.html#viewport/0-examples"},{"type":"macro","title":"Garnish.View.viewport/1","doc":"Defines an element with the `:viewport` tag and either:\n\n* given attributes and an optional block\n* a list of child elements","ref":"Garnish.View.html#viewport/1"},{"type":"macro","title":"Attributes - Garnish.View.viewport/1","doc":"* `offset_x` (optional) - Integer representing the number of columns to offset the child content by. Defaults to 0.\n* `offset_y` (optional) - Integer representing the number of rows to offset the child content by. Defaults to 0.","ref":"Garnish.View.html#viewport/1-attributes"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.viewport/1","doc":"* canvas\n* chart\n* label\n* panel\n* row\n* sparkline\n* table\n* tree\n* viewport\n* progress_bar","ref":"Garnish.View.html#viewport/1-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.viewport/1","doc":"Passing attributes:\n\n    viewport(key: value)\n\nPassing attributes and a block:\n\n    viewport(key: value) do\n      # ...child elements...\n    end\n\nPassing list of children:\n\n    viewport([elem1, elem2])","ref":"Garnish.View.html#viewport/1-examples"},{"type":"macro","title":"Garnish.View.viewport/2","doc":"Defines an element with the `:viewport` tag and the given attributes and\nchild elements.","ref":"Garnish.View.html#viewport/2"},{"type":"macro","title":"Attributes - Garnish.View.viewport/2","doc":"* `offset_x` (optional) - Integer representing the number of columns to offset the child content by. Defaults to 0.\n* `offset_y` (optional) - Integer representing the number of rows to offset the child content by. Defaults to 0.","ref":"Garnish.View.html#viewport/2-attributes"},{"type":"macro","title":"Allowed Child Elements - Garnish.View.viewport/2","doc":"* canvas\n* chart\n* label\n* panel\n* row\n* sparkline\n* table\n* tree\n* viewport\n* progress_bar","ref":"Garnish.View.html#viewport/2-allowed-child-elements"},{"type":"macro","title":"Examples - Garnish.View.viewport/2","doc":"viewport([key: value], [elem1, elem2])","ref":"Garnish.View.html#viewport/2-examples"},{"type":"extras","title":"Garnish","doc":"# Garnish\n\n[![Hex.pm Version](https://img.shields.io/hexpm/v/garnish)](https://hex.pm/packages/garnish)\n![GitHub License](https://img.shields.io/github/license/ausimian/garnish)\n\n\n`Garnish` is a terminal-UI (TUI) framework built around via Erlang's\n[ssh](https://www.erlang.org/doc/apps/ssh/ssh.html) application.\n\n[![asciicast](https://asciinema.org/a/GtXuCsbdVyMub7tWv3Oyw6jry.svg)](https://asciinema.org/a/GtXuCsbdVyMub7tWv3Oyw6jry)","ref":"readme.html"},{"type":"extras","title":"Installation - Garnish","doc":"The package can be installed by adding `garnish` to your list of dependencies\nin `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:garnish, \"~> 0.2.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Architecture - Garnish","doc":"The architecure is heavily based on the approach taken by\n[Ratatouille](https://github.com/ndreynolds/ratatouille) - indeed the _entire_ view\nand rendering code has been copied from that project. The main differences are:\n\n1. The `Garnish.App` behaviour is a little more idiomatic in its callback style.\n2. The result of the rendering process is translated into escape sequences without\n    the ExTermbox NIF requirement.","ref":"readme.html#architecture"},{"type":"extras","title":"SSH Support - Garnish","doc":"To expose your app via ssh, add `ssh` to the list of extra applications in mix.exs\n\n```elixir\ndef application do\n  [\n    extra_applications: [:logger, :ssh, ...],\n    mod: ...\n  ]\nend\n```\n\nand start the ssh daemon e.g. in your application's `start/2` callback:\n\n```elixir\n  @impl true\n  def start(_type, _args) do\n    opts = [\n      # ... other ssh opts\n      ssh_cli: {Garnish, app: My.App}\n    ]\n    {:ok, ref} = :ssh.daemon({127,0,0,1}, 2222, opts)\n\n    children = [\n    ]\n\n    opts = [strategy: :one_for_one, name: My.Supervisor]\n    with {:ok, pid} <- Supervisor.start_link(children, opts) do\n      {:ok, pid, ref}\n    end\n  end\n\n  @impl true\n  def stop(ref) do\n    :ssh.stop_daemon(ref)\n  end\n```\n\nSee the `Garnish.App` behaviour for details of the application model.","ref":"readme.html#ssh-support"},{"type":"extras","title":"Examples - Garnish","doc":"To run the examples, first start the example, e.g.\n\n    > mix run --no-halt examples/counter.exs\n\nand then connect over ssh\n\n    > ssh -o NoHostAuthenticationForLocalhost=yes -p 2222 localhost","ref":"readme.html#examples"},{"type":"extras","title":"Credits - Garnish","doc":"The entire view and logical rendering framework is lifted from\n[Ratatouille](https://github.com/ndreynolds/ratatouille), with some renaming.","ref":"readme.html#credits"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n## [0.2.0] - 2024-11-25","ref":"changelog.html"},{"type":"extras","title":"New features - Changelog","doc":"-  Added support for xterm, linux and rxvt consoles\n\n## [0.1.2] - 2024-08-12","ref":"changelog.html#new-features"},{"type":"extras","title":"Fixed - Changelog","doc":"-  Fixed version in mix file.\n\n## [0.1.1] - 2024-08-12","ref":"changelog.html#fixed"},{"type":"extras","title":"Fixed - Changelog","doc":"-  Added description to Mix project definition.\n\n## [0.1.1] - 2024-08-12","ref":"changelog.html#fixed"},{"type":"extras","title":"Fixed - Changelog","doc":"-  Added description to Mix project definition.\n\n## [0.1.0] - 2024-08-12","ref":"changelog.html#fixed"},{"type":"extras","title":"Known issues - Changelog","doc":"- The logical rendering process is relatively expensive. For views that change\n  substantially and on a frequent basis, it is _not_ web-scale.\n- Only xterm-256color is supported in this release.","ref":"changelog.html#known-issues"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}